==> tine20-allinone_2019.12.5.tar.bz2: Setup/js/Setup-lang-en-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0 - Setup\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "Performing Environment Checks..."
: "Performing Environment Checks..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."

, "Check"
: "Check"

, "Result"
: "Result"

, "Error"
: "Error"

, "Run setup tests"
: "Run setup tests"

, "Ignore setup tests"
: "Ignore setup tests"

, "Install application"
: "Install application"

, "Terms and Conditions"
: "Terms and Conditions"

, "Setup Checks"
: "Setup Checks"

, "Config Manager"
: "Config Manager"

, "Authentication/Accounts"
: "Authentication/Accounts"

, "Email"
: "Email"

, "Application Manager"
: "Application Manager"

, "I have read the license agreement and accept it"
: "I have read the license agreement and accept it"

, "License Agreement"
: "License Agreement"

, "I have read the privacy agreement and accept it"
: "I have read the privacy agreement and accept it"

, "Privacy Agreement"
: "Privacy Agreement"

, "Accept Terms and Conditions"
: "Accept Terms and Conditions"

, "Name"
: "Name"

, "Enabled"
: "Enabled"

, "Order"
: "Order"

, "Installed Version"
: "Installed Version"

, "Available Version"
: "Available Version"

, "Status"
: "Status"

, "Depends on"
: "Depends on"

, "Uninstall application"
: "Uninstall application"

, "Update application"
: "Update application"

, "Go to {0} login"
: "Go to {0} login"

, "uninstall"
: "uninstall"

, "Do you really want to uninstall the application(s)?"
: "Do you really want to uninstall the application(s)?"

, "This may take a while"
: "This may take a while"

, "Dependency Violation"
: "Dependency Violation"

, "CLI Required"
: "CLI Required"

, "Application, Applications"
: [
  "Application"
 ,"Applications"

]
, "Delete all existing users and groups"
: "Delete all existing users and groups"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"

, "Backend"
: "Backend"

, "TLS client certificate"
: "TLS client certificate"

, "Initial Admin User"
: "Initial Admin User"

, "Initial admin login name"
: "Initial admin login name"

, "Initial admin Password"
: "Initial admin Password"

, "Password confirmation"
: "Password confirmation"

, "Authentication provider"
: "Authentication provider"

, "Try to split username"
: "Try to split username"

, "Yes"
: "Yes"

, "No"
: "No"

, "Account canonical form"
: "Account canonical form"

, "Account domain name"
: "Account domain name"

, "Account domain short name"
: "Account domain short name"

, "Host"
: "Host"

, "Port"
: "Port"

, "Login name"
: "Login name"

, "Password"
: "Password"

, "Bind requires DN"
: "Bind requires DN"

, "Start TLS"
: "Start TLS"

, "SSL"
: "SSL"

, "Base DN"
: "Base DN"

, "Search filter"
: "Search filter"

, "Hostname"
: "Hostname"

, "Secure Connection"
: "Secure Connection"

, "None"
: "None"

, "TLS"
: "TLS"

, "Append domain to login name"
: "Append domain to login name"

, "Certificate validation"
: "Certificate validation"

, "CA file"
: "CA file"

, "CRL directory"
: "CRL directory"

, "Accounts storage"
: "Accounts storage"

, "Default user group name"
: "Default user group name"

, "Default admin group name"
: "Default admin group name"

, "Login panel"
: "Login panel"

, "Reuse last username logged"
: "Reuse last username logged"

, "Password Settings"
: "Password Settings"

, "User can change password"
: "User can change password"

, "Enable password policy"
: "Enable password policy"

, "Only ASCII"
: "Only ASCII"

, "Minimum length"
: "Minimum length"

, "Minimum word chars"
: "Minimum word chars"

, "Minimum uppercase chars"
: "Minimum uppercase chars"

, "Minimum special chars"
: "Minimum special chars"

, "Minimum numbers"
: "Minimum numbers"

, "Change password after ... days"
: "Change password after ... days"

, "Forbid part of username in password"
: "Forbid part of username in password"

, "Redirect Settings"
: "Redirect Settings"

, "Redirect Url (redirect to login screen if empty)"
: "Redirect Url (redirect to login screen if empty)"

, "Redirect Always (if No, only redirect after logout)"
: "Redirect Always (if No, only redirect after logout)"

, "Redirect to referring site, if exists"
: "Redirect to referring site, if exists"

, "Password encoding"
: "Password encoding"

, "des"
: "des"

, "crypt"
: "crypt"

, "blowfish_crypt"
: "blowfish_crypt"

, "md5_crypt"
: "md5_crypt"

, "ext_crypt"
: "ext_crypt"

, "md5"
: "md5"

, "smd5"
: "smd5"

, "sha"
: "sha"

, "ssha"
: "ssha"

, "ntpassword"
: "ntpassword"

, "plain"
: "plain"

, "User DN"
: "User DN"

, "User Filter"
: "User Filter"

, "User Search Scope"
: "User Search Scope"

, "Groups DN"
: "Groups DN"

, "Group Filter"
: "Group Filter"

, "Group Search Scope"
: "Group Search Scope"

, "Use Rfc 2307 bis"
: "Use Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: "Maintain RFC 2307 attributes"

, "Min User Id"
: "Min User Id"

, "Max User Id"
: "Max User Id"

, "Min Group Id"
: "Min Group Id"

, "Max Group Id"
: "Max Group Id"

, "Group UUID Attribute name"
: "Group UUID Attribute name"

, "User UUID Attribute name"
: "User UUID Attribute name"

, "Readonly access"
: "Readonly access"

, "Save config and install"
: "Save config and install"

, "Save config"
: "Save config"

, "Passwords don't match"
: "Passwords don't match"

, "Should not be empty"
: "Should not be empty"

, "File"
: "File"

, "Setup Authentication"
: "Setup Authentication"

, "Username"
: "Username"

, "Database"
: "Database"

, "User"
: "User"

, "Prefix"
: "Prefix"

, "Logging"
: "Logging"

, "Filename"
: "Filename"

, "Priority"
: "Priority"

, "Caching"
: "Caching"

, "Lifetime (seconds)"
: "Lifetime (seconds)"

, "Path"
: "Path"

, "Queue"
: "Queue"

, "Session"
: "Session"

, "Temporary files"
: "Temporary files"

, "Temporary Files Path"
: "Temporary Files Path"

, "Filestore directory"
: "Filestore directory"

, "Filestore Path"
: "Filestore Path"

, "Addressbook Map panel"
: "Addressbook Map panel"

, "Map panel"
: "Map panel"

, "disabled"
: "disabled"

, "enabled"
: "enabled"

, "Use Custom Theme"
: "Use Custom Theme"

, "Theme path"
: "Theme path"

, "Use blue theme as base"
: "Use blue theme as base"

, "Config file is not writable"
: "Config file is not writable"

, "Download config file"
: "Download config file"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: "This prefix is too long. Please choose a prefix no longer than {0} chars."

, "Standard IMAP"
: "Standard IMAP"

, "Standard SMTP"
: "Standard SMTP"

, "Imap"
: "Imap"

, "Use system account"
: "Use system account"

, "Use email address as login name"
: "Use email address as login name"

, "Cyrus Admin"
: "Cyrus Admin"

, "Cyrus Admin Password"
: "Cyrus Admin Password"

, "Use proxy auth"
: "Use proxy auth"

, "Smtp"
: "Smtp"

, "Authentication"
: "Authentication"

, "Login"
: "Login"

, "Plain"
: "Plain"

, "Primary Domain"
: "Primary Domain"

, "Secondary Domains (comma separated)"
: "Secondary Domains (comma separated)"

, "Notifications service address"
: "Notifications service address"

, "Notification Username"
: "Notification Username"

, "Notification Password"
: "Notification Password"

, "Notifications local client (hostname or IP address)"
: "Notifications local client (hostname or IP address)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "MySql Hostname"

, "MySql Database"
: "MySql Database"

, "MySql User"
: "MySql User"

, "MySql Password"
: "MySql Password"

, "MySql Port"
: "MySql Port"

, "User or UID"
: "User or UID"

, "Group or GID"
: "Group or GID"

, "Home Template"
: "Home Template"

, "Password Scheme"
: "Password Scheme"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLAIN"

, "Application"
: "Application"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Setup/js/Setup-lang-en-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0 - Setup\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "I have read the license agreement and accept it"
: "I have read the license agreement and accept it"

, "License Agreement"
: "License Agreement"

, "I have read the privacy agreement and accept it"
: "I have read the privacy agreement and accept it"

, "Privacy Agreement"
: "Privacy Agreement"

, "Accept Terms and Conditions"
: "Accept Terms and Conditions"

, "Backend"
: "Backend"

, "Standard IMAP"
: "Standard IMAP"

, "Standard SMTP"
: "Standard SMTP"

, "Imap"
: "Imap"

, "Hostname"
: "Hostname"

, "Username"
: "Username"

, "Password"
: "Password"

, "Port"
: "Port"

, "Secure Connection"
: "Secure Connection"

, "None"
: "None"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: "Verify peer Certificate"

, "Use system account"
: "Use system account"

, "No"
: "No"

, "Yes"
: "Yes"

, "Append domain to login name"
: "Append domain to login name"

, "Use email address as login name"
: "Use email address as login name"

, "Cyrus Admin"
: "Cyrus Admin"

, "Cyrus Admin Password"
: "Cyrus Admin Password"

, "Use proxy auth"
: "Use proxy auth"

, "Smtp"
: "Smtp"

, "Authentication"
: "Authentication"

, "Login"
: "Login"

, "Plain"
: "Plain"

, "Primary Domain"
: "Primary Domain"

, "Secondary Domains (comma separated)"
: "Secondary Domains (comma separated)"

, "Notifications service address"
: "Notifications service address"

, "Notification Username"
: "Notification Username"

, "Notification Password"
: "Notification Password"

, "Notifications local client (hostname or IP address)"
: "Notifications local client (hostname or IP address)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "MySql Hostname"

, "MySql Database"
: "MySql Database"

, "MySql User"
: "MySql User"

, "MySql Password"
: "MySql Password"

, "MySql Port"
: "MySql Port"

, "User or UID"
: "User or UID"

, "Group or GID"
: "Group or GID"

, "Home Template"
: "Home Template"

, "Password Scheme"
: "Password Scheme"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLAIN"

, "Terms and Conditions"
: "Terms and Conditions"

, "Setup Checks"
: "Setup Checks"

, "Config Manager"
: "Config Manager"

, "Authentication/Accounts"
: "Authentication/Accounts"

, "Email"
: "Email"

, "Application Manager"
: "Application Manager"

, "Setup"
: "Setup"

, "Name"
: "Name"

, "Enabled"
: "Enabled"

, "Order"
: "Order"

, "Installed Version"
: "Installed Version"

, "Available Version"
: "Available Version"

, "Status"
: "Status"

, "Depends on"
: "Depends on"

, "Install application"
: "Install application"

, "Uninstall application"
: "Uninstall application"

, "Update application"
: "Update application"

, "Go to {0} login"
: "Go to {0} login"

, "uninstall"
: "uninstall"

, "Do you really want to uninstall the application(s)?"
: "Do you really want to uninstall the application(s)?"

, "This may take a while"
: "This may take a while"

, "Dependency Violation"
: "Dependency Violation"

, "CLI Required"
: "CLI Required"

, "Delete all existing users and groups"
: "Delete all existing users and groups"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"

, "TLS client certificate"
: "TLS client certificate"

, "Initial Admin User"
: "Initial Admin User"

, "Initial admin login name"
: "Initial admin login name"

, "Initial admin Password"
: "Initial admin Password"

, "Password confirmation"
: "Password confirmation"

, "Authentication provider"
: "Authentication provider"

, "Try to split username"
: "Try to split username"

, "Account canonical form"
: "Account canonical form"

, "Account domain name"
: "Account domain name"

, "Account domain short name"
: "Account domain short name"

, "Host"
: "Host"

, "Login name"
: "Login name"

, "Bind requires DN"
: "Bind requires DN"

, "Start TLS"
: "Start TLS"

, "Base DN"
: "Base DN"

, "Search filter"
: "Search filter"

, "Certificate validation"
: "Certificate validation"

, "CA file"
: "CA file"

, "CRL directory"
: "CRL directory"

, "Accounts storage"
: "Accounts storage"

, "Default user group name"
: "Default user group name"

, "Default admin group name"
: "Default admin group name"

, "Login panel"
: "Login panel"

, "Reuse last username logged"
: "Reuse last username logged"

, "Password Settings"
: "Password Settings"

, "User can change password"
: "User can change password"

, "Enable password policy"
: "Enable password policy"

, "Only ASCII"
: "Only ASCII"

, "Minimum length"
: "Minimum length"

, "Minimum word chars"
: "Minimum word chars"

, "Minimum uppercase chars"
: "Minimum uppercase chars"

, "Minimum special chars"
: "Minimum special chars"

, "Minimum numbers"
: "Minimum numbers"

, "Change password after ... days"
: "Change password after ... days"

, "Forbid part of username in password"
: "Forbid part of username in password"

, "Redirect Settings"
: "Redirect Settings"

, "Redirect Url (redirect to login screen if empty)"
: "Redirect Url (redirect to login screen if empty)"

, "Redirect Always (if No, only redirect after logout)"
: "Redirect Always (if No, only redirect after logout)"

, "Redirect to referring site, if exists"
: "Redirect to referring site, if exists"

, "Password encoding"
: "Password encoding"

, "des"
: "des"

, "crypt"
: "crypt"

, "blowfish_crypt"
: "blowfish_crypt"

, "md5_crypt"
: "md5_crypt"

, "ext_crypt"
: "ext_crypt"

, "md5"
: "md5"

, "smd5"
: "smd5"

, "sha"
: "sha"

, "ssha"
: "ssha"

, "ntpassword"
: "ntpassword"

, "plain"
: "plain"

, "User DN"
: "User DN"

, "User Filter"
: "User Filter"

, "User Search Scope"
: "User Search Scope"

, "Groups DN"
: "Groups DN"

, "Group Filter"
: "Group Filter"

, "Group Search Scope"
: "Group Search Scope"

, "Use Rfc 2307 bis"
: "Use Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: "Maintain RFC 2307 attributes"

, "Min User Id"
: "Min User Id"

, "Max User Id"
: "Max User Id"

, "Min Group Id"
: "Min Group Id"

, "Max Group Id"
: "Max Group Id"

, "Group UUID Attribute name"
: "Group UUID Attribute name"

, "User UUID Attribute name"
: "User UUID Attribute name"

, "Readonly access"
: "Readonly access"

, "Save config and install"
: "Save config and install"

, "Save config"
: "Save config"

, "Passwords don't match"
: "Passwords don't match"

, "Should not be empty"
: "Should not be empty"

, "Performing Environment Checks..."
: "Performing Environment Checks..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."

, "Check"
: "Check"

, "Result"
: "Result"

, "Error"
: "Error"

, "Run setup tests"
: "Run setup tests"

, "Ignore setup tests"
: "Ignore setup tests"

, "Application, Applications"
: [
  "Application"
 ,"Applications"

]
, "File"
: "File"

, "Setup Authentication"
: "Setup Authentication"

, "Database"
: "Database"

, "User"
: "User"

, "Prefix"
: "Prefix"

, "Logging"
: "Logging"

, "Filename"
: "Filename"

, "Priority"
: "Priority"

, "Caching"
: "Caching"

, "Lifetime (seconds)"
: "Lifetime (seconds)"

, "Path"
: "Path"

, "Queue"
: "Queue"

, "Session"
: "Session"

, "Temporary files"
: "Temporary files"

, "Temporary Files Path"
: "Temporary Files Path"

, "Filestore directory"
: "Filestore directory"

, "Filestore Path"
: "Filestore Path"

, "Addressbook Map panel"
: "Addressbook Map panel"

, "Map panel"
: "Map panel"

, "disabled"
: "disabled"

, "enabled"
: "enabled"

, "Config file is not writable"
: "Config file is not writable"

, "Download config file"
: "Download config file"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: "This prefix is too long. Please choose a prefix no longer than {0} chars."

, "Application"
: "Application"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
